summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameSet.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
committerTimothy Pearson <[email protected]>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kword/KWFrameSet.cpp
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kword/KWFrameSet.cpp')
-rw-r--r--kword/KWFrameSet.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kword/KWFrameSet.cpp b/kword/KWFrameSet.cpp
index 515b0df0..d1129b1f 100644
--- a/kword/KWFrameSet.cpp
+++ b/kword/KWFrameSet.cpp
@@ -292,7 +292,7 @@ void KWFrameSet::setFloating()
frameSet->findPosition( dPoint, parag, index );
// Create anchor. TODO: refcount the anchors!
setAnchored( frameSet, parag, index );
- frameSet->layout();
+ frameSet->tqlayout();
m_doc->frameChanged( m_frames.first() );
return;
}
@@ -303,15 +303,15 @@ void KWFrameSet::setProtectSize( bool b)
m_protectSize = b;
}
-void KWFrameSet::setAnchored( KWTextFrameSet* textfs, int paragId, int index, bool placeHolderExists /* = false */, bool repaint )
+void KWFrameSet::setAnchored( KWTextFrameSet* textfs, int paragId, int index, bool placeHolderExists /* = false */, bool tqrepaint )
{
KWTextParag * parag = static_cast<KWTextParag *>( textfs->textDocument()->paragAt( paragId ) );
Q_ASSERT( parag );
if ( parag )
- setAnchored( textfs, parag, index, placeHolderExists, repaint );
+ setAnchored( textfs, parag, index, placeHolderExists, tqrepaint );
}
-void KWFrameSet::setAnchored( KWTextFrameSet* textfs, KoTextParag* parag, int index, bool placeHolderExists /* = false */, bool repaint )
+void KWFrameSet::setAnchored( KWTextFrameSet* textfs, KoTextParag* parag, int index, bool placeHolderExists /* = false */, bool tqrepaint )
{
kdDebug(32001) << "KWFrameSet::setAnchored " << textfs << " " << parag->paragId() << " " << index << " " << placeHolderExists << endl;
Q_ASSERT( textfs );
@@ -321,7 +321,7 @@ void KWFrameSet::setAnchored( KWTextFrameSet* textfs, KoTextParag* parag, int in
m_anchorTextFs = textfs;
KWFrameList::createFrameList(textfs, m_doc); // remove ourselves from others list now we are inline
if ( parag )
- createAnchors( parag, index, placeHolderExists, repaint );
+ createAnchors( parag, index, placeHolderExists, tqrepaint );
if ( !placeHolderExists ) // i.e. not while loading
{
@@ -381,7 +381,7 @@ KWAnchor * KWFrameSet::createAnchor( KoTextDocument *txt, int frameNum )
}
void KWFrameSet::createAnchors( KoTextParag * parag, int index, bool placeHolderExists /*= false */ /*only used when loading*/,
- bool repaint )
+ bool tqrepaint )
{
kdDebug(32001) << "KWFrameSet::createAnchors" << endl;
Q_ASSERT( m_anchorTextFs );
@@ -398,7 +398,7 @@ void KWFrameSet::createAnchors( KoTextParag * parag, int index, bool placeHolder
}
}
parag->setChanged( true );
- if ( repaint )
+ if ( tqrepaint )
emit repaintChanged( m_anchorTextFs );
}
@@ -460,7 +460,7 @@ void KWFrameSet::moveFloatingFrame( int frameNum, const KoPoint &position )
if( frame->frameStack() )
frame->frameStack()->updateAfterMove( oldPageNum );
}
- invalidate();
+ tqinvalidate();
}
KoRect KWFrameSet::floatingFrameRect( int frameNum )
@@ -789,7 +789,7 @@ void KWFrameSet::drawFrame( KWFrame *frame, TQPainter *painter, const TQRect &fc
doubleBufPainter->begin( pix );
// Initialize the pixmap to the page background color
// (if the frame is over the page margins, no underlying frame will paint anything there)
- doubleBufPainter->fillRect( 0, 0, outerCRect.width(), outerCRect.height(), TQApplication::palette().active().brush( TQColorGroup::Base ) );
+ doubleBufPainter->fillRect( 0, 0, outerCRect.width(), outerCRect.height(), TQApplication::tqpalette().active().brush( TQColorGroup::Base ) );
// The double-buffer pixmap has (0,0) at outerCRect.topLeft(), so we need to
// translate the double-buffer painter; drawFrameAndBorders will draw using view coordinates.
@@ -828,7 +828,7 @@ void KWFrameSet::drawFrame( KWFrame *frame, TQPainter *painter, const TQRect &fc
kdDebug(32001) << " translating by " << translationOffset.x() << ", " << translationOffset.y() << " before drawFrameContents" << endl;
#endif
doubleBufPainter->translate( translationOffset.x(), translationOffset.y() ); // This assume that viewToNormal() is only a translation
// We can't "repaint changed parags only" if we just drew the underlying frames, hence the "false"
drawFrameContents( frame, doubleBufPainter, fcrect, frameColorGroup, false, resetChanged, edit, viewMode );
doubleBufPainter->restore();
@@ -828,7 +828,7 @@ void KWFrameSet::drawFrame( KWFrame *frame, TQPainter *painter, const TQRect &fc
#endif
doubleBufPainter->translate( translationOffset.x(), translationOffset.y() ); // This assume that viewToNormal() is only a translation
- // We can't "repaint changed parags only" if we just drew the underlying frames, hence the "false"
+ // We can't "tqrepaint changed parags only" if we just drew the underlying frames, hence the "false"
drawFrameContents( frame, doubleBufPainter, fcrect, frameColorGroup, false, resetChanged, edit, viewMode );
doubleBufPainter->restore();